@@ -58,7 +58,12 @@ from duplicity import path
 from duplicity import progress
 from duplicity import tempdir
 from duplicity import util
+import duplicity.errors
+from duplicity.errors import BadVolumeException
 
+import duplicity.config as config
+
+from datetime import datetime
 
 # If exit_val is not None, exit with given value at end.
 exit_val = None
@@ -140,16 +145,18 @@ def get_passphrase(n, action, for_signing=False):
 
     # for a full backup, we don't need a password if
     # there is no sign_key and there are recipients
-    elif (action == u"full" and
-          (config.gpg_profile.recipients or config.gpg_profile.hidden_recipients) and not
-          config.gpg_profile.sign_key):
+    elif (action == u"full"
+          and (config.gpg_profile.recipients or config.gpg_profile.hidden_recipients)
+          and (not config.gpg_profile.sign_key
+               or (not config.restart and not for_signing))):
         return u""
 
     # for an inc backup, we don't need a password if
     # there is no sign_key and there are recipients
-    elif (action == u"inc" and
-          (config.gpg_profile.recipients or config.gpg_profile.hidden_recipients) and not
-          config.gpg_profile.sign_key):
+    elif (action == u"inc"
+          and (config.gpg_profile.recipients or config.gpg_profile.hidden_recipients)
+          and (not config.gpg_profile.sign_key
+               or (not config.restart and not for_signing))):
         return u""
 
     # Finally, ask the user for the passphrase
@@ -174,14 +181,14 @@ def get_passphrase(n, action, for_signing=False):
                     if use_cache and config.gpg_profile.passphrase:
                         pass1 = config.gpg_profile.passphrase
                     else:
-                        pass1 = getpass_safe(_(u"GnuPG passphrase:") + u" ")
+                        pass1 = getpass_safe(_(u"GnuPG passphrase for decryption:") + u" ")
 
             if n == 1:
                 pass2 = pass1
             elif for_signing:
                 pass2 = getpass_safe(_(u"Retype passphrase for signing key to confirm: "))
             else:
-                pass2 = getpass_safe(_(u"Retype passphrase to confirm: "))
+                pass2 = getpass_safe(_(u"Retype passphrase for decryption to confirm: "))
 
             if not pass1 == pass2:
                 log.Log(_(u"First and second passphrases do not match!  Please try again."),
@@ -304,6 +311,16 @@ def write_multivol(backup_type, tarblock_iter, man_outfp, sig_outfp, backend):
         size = info[u'size']
         if size is None:
             return  # error querying file
+        for attempt in range(1, config.num_retries + 1):
+            info = backend.query_info([dest_filename])[dest_filename]
+            size = info[u'size']
+            if size == orig_size:
+                break
+            if size is None:
+                return
+            log.Notice(_(u"%s Remote filesize %d for %s does not match local size %d, retrying.") % (datetime.now(),
+                       size, util.escape(dest_filename), orig_size))
+            time.sleep(2**attempt)
         if size != orig_size:
             code_extra = u"%s %d %d" % (util.escape(dest_filename), orig_size, size)
             log.FatalError(_(u"File %s was corrupted during upload.") % util.fsdecode(dest_filename),
@@ -366,7 +383,10 @@ def write_multivol(backup_type, tarblock_iter, man_outfp, sig_outfp, backend):
         mf = config.restart.last_backup.get_local_manifest()
         config.restart.checkManifest(mf)
         config.restart.setLastSaved(mf)
-        validate_encryption_settings(config.restart.last_backup, mf)
+        if not (config.s3_use_deep_archive or config.s3_use_glacier):
+            validate_encryption_settings(config.restart.last_backup, mf)
+        else:
+            log.Warn(_(u"Skipping encryption validation due to glacier/deep storage"))
         mf.fh = man_outfp
         last_block = config.restart.last_block
         log.Notice(_(u"Restarting after volume %s, file %s, block %s") %
@@ -709,6 +729,8 @@ def restore(col_stats):
     @return: void
     """
     if config.dry_run:
+        # Only prints list of required volumes when running dry
+        restore_get_patched_rop_iter(col_stats)
         return
     if not patchdir.Write_ROPaths(config.local_path,
                                   restore_get_patched_rop_iter(col_stats)):
@@ -746,21 +768,30 @@ def restore_get_patched_rop_iter(col_stats):
         manifest = backup_set.get_manifest()
         volumes = manifest.get_containing_volumes(index)
         for vol_num in volumes:
-            yield restore_get_enc_fileobj(backup_set.backend,
-                                          backup_set.volume_name_dict[vol_num],
-                                          manifest.volume_info_dict[vol_num])
+            try:
+                yield restore_get_enc_fileobj(backup_set.backend,
+                                              backup_set.volume_name_dict[vol_num],
+                                              manifest.volume_info_dict[vol_num])
+            except BadVolumeException as e:
+                yield e
+
             cur_vol[0] += 1
             log.Progress(_(u'Processed volume %d of %d') % (cur_vol[0], num_vols),
                          cur_vol[0], num_vols)
 
-    if hasattr(config.backend, u'pre_process_download'):
+    if hasattr(config.backend, u'pre_process_download_batch') or config.dry_run:
         file_names = []
         for backup_set in backup_setlist:
             manifest = backup_set.get_manifest()
             volumes = manifest.get_containing_volumes(index)
             for vol_num in volumes:
                 file_names.append(backup_set.volume_name_dict[vol_num])
-        config.backend.pre_process_download(file_names)
+        if config.dry_run:
+            log.Notice(u"Required volumes to restore:\n\t" +
+                       u'\n\t'.join(file_name.decode() for file_name in file_names))
+            return None
+        else:
+            config.backend.pre_process_download_batch(file_names)
 
     fileobj_iters = list(map(get_fileobj_iter, backup_setlist))
     tarfiles = list(map(patchdir.TarFile_FromFileobjs, fileobj_iters))
@@ -775,6 +806,8 @@ def restore_get_enc_fileobj(backend, filename, volume_info):
     assuming some hash is available.  Also, if config.sign_key is
     set, a fatal error will be raised if file not signed by sign_key.
 
+    with --ignore-errors set continue on hash mismatch
+
     """
     parseresults = file_naming.parse(filename)
     tdp = dup_temp.new_tempduppath(parseresults)
@@ -783,14 +816,21 @@ def restore_get_enc_fileobj(backend, filename, volume_info):
     u""" verify hash of the remote file """
     verified, hash_pair, calculated_hash = restore_check_hash(volume_info, tdp)
     if not verified:
-        log.FatalError(u"%s\n %s\n %s\n %s\n" %
-                       (_(u"Invalid data - %s hash mismatch for file:") %
-                        hash_pair[0],
-                        util.fsdecode(filename),
-                        _(u"Calculated hash: %s") % calculated_hash,
-                        _(u"Manifest hash: %s") % hash_pair[1]),
-                       log.ErrorCode.mismatched_hash)
-
+        error_msg = u"%s\n %s\n %s\n %s\n" % (
+            _(u"Invalid data - %s hash mismatch for file:") %
+            hash_pair[0],
+            util.fsdecode(filename),
+            _(u"Calculated hash: %s") % calculated_hash,
+            _(u"Manifest hash: %s") % hash_pair[1]
+        )
+        if config.ignore_errors:
+            exc = duplicity.errors.BadVolumeException(u"Hash mismatch for: %s" % util.fsdecode(filename))
+            log.Log(error_msg, log.ERROR, code=log.ErrorCode.mismatched_hash)
+            log.Warn(_(u"IGNORED_ERROR: Warning: ignoring error as requested: %s: %s")
+                     % (exc.__class__.__name__, util.uexc(exc)))
+            raise exc
+        else:
+            log.FatalError(error_msg, code=log.ErrorCode.mismatched_hash)
     fileobj = tdp.filtered_open_with_delete(u"rb")
     if parseresults.encrypted and config.gpg_profile.sign_key:
         restore_add_sig_check(fileobj)
@@ -1330,8 +1370,8 @@ def sync_archive(col_stats):
                 config.gpg_profile.passphrase = get_passphrase(1, u"sync")
             for fn in local_spurious:
                 remove_local(fn)
-            if hasattr(config.backend, u'pre_process_download'):
-                config.backend.pre_process_download(local_missing)
+            if hasattr(config.backend, u'pre_process_download_batch'):
+                config.backend.pre_process_download_batch(local_missing)
             for fn in local_missing:
                 copy_to_local(fn)
             col_stats.set_values()
@@ -1364,8 +1404,8 @@ def check_last_manifest(col_stats):
 def check_resources(action):
     u"""
     Check for sufficient resources:
-      - temp space for volume build
-      - enough max open files
+    - temp space for volume build
+    - enough max open files
     Put out fatal error if not sufficient to run
 
     @type action: string
@@ -1550,7 +1590,12 @@ def do_backup(action):
                                                   action).set_values()
 
     # check archive synch with remote, fix if needed
-    if action not in [u"collection-status", u"replicate"]:
+    if action not in [u"collection-status",
+                      u"remove-all-but-n-full",
+                      u"remove-all-inc-of-but-n-full",
+                      u"remove-old",
+                      u"replicate",
+                      ]:
         sync_archive(col_stats)
 
     while True:
@@ -1599,8 +1644,6 @@ def do_backup(action):
         action = u"full"
     log.PrintCollectionStatus(col_stats)
 
-    os.umask(0o77)
-
     # get the passphrase if we need to based on action/options
     config.gpg_profile.passphrase = get_passphrase(1, action)
 
