@@ -30,6 +30,7 @@ import subprocess
 import sys
 import unittest
 
+from testing import _runtest_dir
 from . import FunctionalTestCase
 
 
@@ -43,9 +44,9 @@ class RestartTest(FunctionalTestCase):
         Test basic Checkpoint/Restart
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/largefiles", fail=1)
-        self.backup(u"full", u"testfiles/largefiles")
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=1)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_multiple_checkpoint_restart(self):
@@ -53,11 +54,11 @@ class RestartTest(FunctionalTestCase):
         Test multiple Checkpoint/Restart
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/largefiles", fail=1)
-        self.backup(u"full", u"testfiles/largefiles", fail=2)
-        self.backup(u"full", u"testfiles/largefiles", fail=3)
-        self.backup(u"full", u"testfiles/largefiles")
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=1)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=2)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=3)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_first_volume_failure(self):
@@ -66,10 +67,10 @@ class RestartTest(FunctionalTestCase):
         Caused when duplicity fails before the first transfer.
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/largefiles", fail=1)
-        assert not os.system(u"rm testfiles/output/duplicity-full*difftar*")
-        self.backup(u"full", u"testfiles/largefiles")
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=1)
+        assert not os.system(u"rm {0}/testfiles/output/duplicity-full*difftar*".format(_runtest_dir))
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_multi_volume_failure(self):
@@ -79,10 +80,10 @@ class RestartTest(FunctionalTestCase):
         fails the last queued transfer(s).
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/largefiles", fail=3)
-        assert not os.system(u"rm testfiles/output/duplicity-full*vol[23].difftar*")
-        self.backup(u"full", u"testfiles/largefiles")
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=3)
+        assert not os.system(u"rm {0}/testfiles/output/duplicity-full*vol[23].difftar*".format(_runtest_dir))
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_restart_encrypt_without_password(self):
@@ -95,11 +96,11 @@ class RestartTest(FunctionalTestCase):
         self.set_environ(u'SIGN_PASSPHRASE', None)
         self.make_largefiles()
         enc_opts = [u"--encrypt-key", self.encrypt_key1]
-        self.backup(u"full", u"testfiles/largefiles", options=enc_opts, fail=2)
-        self.backup(u"full", u"testfiles/largefiles", options=enc_opts)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), options=enc_opts, fail=2)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), options=enc_opts)
 
         self.set_environ(u'PASSPHRASE', self.sign_passphrase)
-        self.verify(u"testfiles/largefiles")
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_restart_sign_and_encrypt(self):
@@ -109,9 +110,9 @@ class RestartTest(FunctionalTestCase):
         """
         self.make_largefiles()
         enc_opts = [u"--sign-key", self.sign_key, u"--encrypt-key", self.sign_key]
-        self.backup(u"full", u"testfiles/largefiles", options=enc_opts, fail=2)
-        self.backup(u"full", u"testfiles/largefiles", options=enc_opts)
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), options=enc_opts, fail=2)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), options=enc_opts)
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_restart_sign_and_hidden_encrypt(self):
@@ -121,9 +122,9 @@ class RestartTest(FunctionalTestCase):
         """
         self.make_largefiles()
         enc_opts = [u"--sign-key", self.sign_key, u"--hidden-encrypt-key", self.sign_key]
-        self.backup(u"full", u"testfiles/largefiles", options=enc_opts, fail=2)
-        self.backup(u"full", u"testfiles/largefiles", options=enc_opts)
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), options=enc_opts, fail=2)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), options=enc_opts)
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     def test_last_file_missing_in_middle(self):
         u"""
@@ -132,10 +133,10 @@ class RestartTest(FunctionalTestCase):
         the file in the middle of the backup, with files following.
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/largefiles", fail=3)
-        assert not os.system(u"rm testfiles/largefiles/file2")
-        self.backup(u"full", u"testfiles/largefiles")
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=3)
+        assert not os.system(u"rm {0}/testfiles/largefiles/file2".format(_runtest_dir))
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     @unittest.skipIf(u"ppc64el" in platform.machine(), u"Skip on ppc64el machines")
     def test_last_file_missing_at_end(self):
@@ -145,20 +146,20 @@ class RestartTest(FunctionalTestCase):
         the file at the end of the backup, with no files following.
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/largefiles", fail=6)
-        assert not os.system(u"rm testfiles/largefiles/file3")
-        self.backup(u"full", u"testfiles/largefiles")
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=6)
+        assert not os.system(u"rm {0}/testfiles/largefiles/file3".format(_runtest_dir))
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     def test_restart_incremental(self):
         u"""
         Test restarting an incremental backup
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/dir1")
-        self.backup(u"inc", u"testfiles/largefiles", fail=2)
-        self.backup(u"inc", u"testfiles/largefiles")
-        self.verify(u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/dir1".format(_runtest_dir))
+        self.backup(u"inc", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=2)
+        self.backup(u"inc", u"{0}/testfiles/largefiles".format(_runtest_dir))
+        self.verify(u"{0}/testfiles/largefiles".format(_runtest_dir))
 
     def make_fake_second_volume(self, name):
         u"""
@@ -168,39 +169,39 @@ class RestartTest(FunctionalTestCase):
         found because it may have not finished uploading.)
         """
         # First, confirm that we have signs of a successful backup
-        self.assertEqual(len(glob.glob(u"testfiles/output/*.manifest*")), 1)
-        self.assertEqual(len(glob.glob(u"testfiles/output/*.sigtar*")), 1)
-        self.assertEqual(len(glob.glob(u"testfiles/cache/%s/*" % name)), 3)
+        self.assertEqual(len(glob.glob(u"{0}/testfiles/output/*.manifest*".format(_runtest_dir))), 1)
+        self.assertEqual(len(glob.glob(u"{0}/testfiles/output/*.sigtar*".format(_runtest_dir))), 1)
+        self.assertEqual(len(glob.glob(u"{0}/testfiles/cache/{1}/*".format(_runtest_dir, name))), 2)
         self.assertEqual(len(glob.glob(
-            u"testfiles/cache/%s/*.manifest*" % name)), 1)
+            u"{0}/testfiles/cache/{1}/*.manifest*".format(_runtest_dir, name))), 1)
         self.assertEqual(len(glob.glob(
-            u"testfiles/cache/%s/*.sigtar*" % name)), 1)
+            u"{0}/testfiles/cache/{1}/*.sigtar*".format(_runtest_dir, name))), 1)
         # Alright, everything is in order; fake a second interrupted volume
-        assert not os.system(u"rm testfiles/output/*.manifest*")
-        assert not os.system(u"rm testfiles/output/*.sigtar*")
-        assert not os.system(u"rm -f testfiles/output/*.vol[23456789].*")
-        assert not os.system(u"rm -f testfiles/output/*.vol1[^.]+.*")
-        self.assertEqual(len(glob.glob(u"testfiles/output/*.difftar*")), 1)
-        assert not os.system(u"rm testfiles/cache/%s/*.sigtar*" % name)
-        assert not os.system(u"cp testfiles/output/*.difftar* "
-                             u"`ls testfiles/output/*.difftar* | "
+        assert not os.system(u"rm {0}/testfiles/output/*.manifest*".format(_runtest_dir))
+        assert not os.system(u"rm {0}/testfiles/output/*.sigtar*".format(_runtest_dir))
+        assert not os.system(u"rm -f {0}/testfiles/output/*.vol[23456789].*".format(_runtest_dir))
+        assert not os.system(u"rm -f {0}/testfiles/output/*.vol1[^.]+.*".format(_runtest_dir))
+        self.assertEqual(len(glob.glob(u"{0}/testfiles/output/*.difftar*".format(_runtest_dir))), 1)
+        assert not os.system(u"rm {0}/testfiles/cache/{1}/*.sigtar*".format(_runtest_dir, name))
+        assert not os.system(u"cp {0}/testfiles/output/*.difftar* ".format(_runtest_dir) +
+                             u"`ls {0}/testfiles/output/*.difftar* | ".format(_runtest_dir) +
                              u" sed 's|vol1|vol2|'`")
-        assert not os.system(u"head -n6 testfiles/cache/%s/*.manifest > "
-                             u"testfiles/cache/%s/"
-                             u"`basename testfiles/cache/%s/*.manifest`"
-                             u".part" % (name, name, name))
-        assert not os.system(u"rm testfiles/cache/%s/*.manifest" % name)
+        assert not os.system(u"head -n6 {0}/testfiles/cache/{1}/*.manifest > ".format(_runtest_dir, name) +
+                             u"{0}/testfiles/cache/{1}/".format(_runtest_dir, name) +
+                             u"`basename {0}/testfiles/cache/{1}/*.manifest`".format(_runtest_dir, name) +
+                             u".part")
+        assert not os.system(u"rm {0}/testfiles/cache/{1}/*.manifest".format(_runtest_dir, name))
         assert not os.system(u"""echo 'Volume 2:
     StartingPath   foo
     EndingPath     bar
-    Hash SHA1 sha1' >> testfiles/cache/%s/*.manifest.part""" % name)
+    Hash SHA1 sha1' >> {0}/testfiles/cache/{1}/*.manifest.part""".format(_runtest_dir, name))
 
     def test_split_after_small(self):
         u"""
         If we restart right after a volume that ended with a small
         (one-block) file, make sure we restart in the right place.
         """
-        source = u'testfiles/largefiles'
+        source = u'{0}/testfiles/largefiles'.format(_runtest_dir)
         assert not os.system(u"mkdir -p %s" % source)
         assert not os.system(u"echo hello > %s/file1" % source)
         self.backup(u"full", source, options=[u"--name=backup1"])
@@ -211,17 +212,17 @@ class RestartTest(FunctionalTestCase):
         # 'restart' the backup
         self.backup(u"full", source, options=[u"--name=backup1"])
         # Confirm we actually resumed the previous backup
-        self.assertEqual(len(os.listdir(u"testfiles/output")), 4)
+        self.assertEqual(len(os.listdir(u"{0}/testfiles/output".format(_runtest_dir))), 4)
         # Now make sure everything is byte-for-byte the same once restored
         self.restore()
-        assert not os.system(u"diff -r %s testfiles/restore_out" % source)
+        assert not os.system(u"diff -r {1} {0}/testfiles/restore_out".format(_runtest_dir, source))
 
     def test_split_after_large(self):
         u"""
         If we restart right after a volume that ended with a large
         (multi-block) file, make sure we restart in the right place.
         """
-        source = u'testfiles/largefiles'
+        source = u'{0}/testfiles/largefiles'.format(_runtest_dir)
         self.make_largefiles(count=1, size=1)
         self.backup(u"full", source, options=[u"--volsize=5", u"--name=backup1"])
         # Fake an interruption
@@ -231,17 +232,17 @@ class RestartTest(FunctionalTestCase):
         # 'restart' the backup
         self.backup(u"full", source, options=[u"--volsize=5", u"--name=backup1"])
         # Confirm we actually resumed the previous backup
-        self.assertEqual(len(os.listdir(u"testfiles/output")), 4)
+        self.assertEqual(len(os.listdir(u"{0}/testfiles/output".format(_runtest_dir))), 4)
         # Now make sure everything is byte-for-byte the same once restored
         self.restore()
-        assert not os.system(u"diff -r %s testfiles/restore_out" % source)
+        assert not os.system(u"diff -r %s {0}/testfiles/restore_out".format(_runtest_dir) % source)
 
     def test_split_inside_large(self):
         u"""
         If we restart right after a volume that ended inside of a large
         (multi-block) file, make sure we restart in the right place.
         """
-        source = u'testfiles/largefiles'
+        source = u'{0}/testfiles/largefiles'.format(_runtest_dir)
         self.make_largefiles(count=1, size=3)
         self.backup(u"full", source, options=[u"--name=backup1"])
         # Fake an interruption
@@ -250,7 +251,7 @@ class RestartTest(FunctionalTestCase):
         self.backup(u"full", source, options=[u"--name=backup1"])
         # Now make sure everything is byte-for-byte the same once restored
         self.restore()
-        assert not os.system(u"diff -r %s testfiles/restore_out" % source)
+        assert not os.system(u"diff -r {0} {1}/testfiles/restore_out".format(source, _runtest_dir))
 
     def test_new_file(self):
         u"""
@@ -259,7 +260,7 @@ class RestartTest(FunctionalTestCase):
         (Expected result is to ignore new, ealier files, but pick up later
         ones.)
         """
-        source = u'testfiles/largefiles'
+        source = u'{0}/testfiles/largefiles'.format(_runtest_dir)
         self.make_largefiles(count=1, size=1)
         self.backup(u"full", source, options=[u"--name=backup1"])
         # Fake an interruption
@@ -271,9 +272,9 @@ class RestartTest(FunctionalTestCase):
         self.backup(u"full", source, options=[u"--name=backup1"])
         # Now make sure everything is the same once restored, except 'a'
         self.restore()
-        assert not os.system(u"test ! -e testfiles/restore_out/a")
-        assert not os.system(u"diff %s/file1 testfiles/restore_out/file1" % source)
-        assert not os.system(u"diff %s/z testfiles/restore_out/z" % source)
+        assert not os.system(u"test ! -e {0}/testfiles/restore_out/a".format(_runtest_dir))
+        assert not os.system(u"diff {0}/file1 {1}/testfiles/restore_out/file1".format(source, _runtest_dir))
+        assert not os.system(u"diff {0}/z {1}/testfiles/restore_out/z".format(source, _runtest_dir))
 
     @unittest.skipIf(sys.version_info.major == 2, u"Skip on possible timing error")
     def test_changed_source_dangling_manifest_volume(self):
@@ -284,11 +285,11 @@ class RestartTest(FunctionalTestCase):
         if the source data changes to be small enough to not create a vol3 on
         restart.
         """
-        source = u'testfiles/largefiles'
+        source = u'{0}/testfiles/largefiles'.format(_runtest_dir)
         self.make_largefiles(count=5, size=1)
         self.backup(u"full", source, fail=3)
         # now delete the last volume on remote end and some source files
-        assert not os.system(u"rm testfiles/output/duplicity-full*vol3.difftar*")
+        assert not os.system(u"rm {0}/testfiles/output/duplicity-full*vol3.difftar*".format(_runtest_dir))
         assert not os.system(u"rm %s/file[2345]" % source)
         assert not os.system(u"echo hello > %s/z" % source)
         # finish backup
@@ -303,7 +304,7 @@ class RestartTest(FunctionalTestCase):
         possible that the first chunk of the next file will be skipped unless
         we're careful.
         """
-        source = u'testfiles/largefiles'
+        source = u'{0}/testfiles/largefiles'.format(_runtest_dir)
         self.make_largefiles(count=1)
         self.backup(u"full", source, fail=2)
         # now remove starting source data and make sure we add something after
@@ -313,7 +314,7 @@ class RestartTest(FunctionalTestCase):
         self.backup(u"full", source)
         # and verify we can restore
         self.restore()
-        assert not os.system(u"diff %s/z testfiles/restore_out/z" % source)
+        assert not os.system(u"diff {0}/z {1}/testfiles/restore_out/z".format(source, _runtest_dir))
 
 
 # Note that this class duplicates all the tests in RestartTest
@@ -331,10 +332,10 @@ class RestartTestWithoutEncryption(RestartTest):
         https://launchpad.net/bugs/929067
         """
         self.make_largefiles()
-        self.backup(u"full", u"testfiles/largefiles", fail=2)
-        self.backup(u"full", u"testfiles/largefiles")
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir), fail=2)
+        self.backup(u"full", u"{0}/testfiles/largefiles".format(_runtest_dir))
         # Now check sigtar
-        sigtars = glob.glob(u"testfiles/output/duplicity-full*.sigtar.gz")
+        sigtars = glob.glob(u"{0}/testfiles/output/duplicity-full*.sigtar.gz".format(_runtest_dir))
         self.assertEqual(1, len(sigtars))
         sigtar = sigtars[0]
         output = subprocess.Popen([u"tar", u"t", u"--file=%s" % sigtar], stdout=subprocess.PIPE).communicate()[0]
@@ -359,28 +360,28 @@ class RestartTestWithoutEncryption(RestartTest):
             raise Exception(u"Platform %s not supported by tar/gtar." % platform.platform())
 
         # Intial normal backup
-        self.backup(u"full", u"testfiles/blocktartest")
+        self.backup(u"full", u"{0}/testfiles/blocktartest".format(_runtest_dir))
         # Create an exact clone of the snapshot folder in the sigtar already.
         # Permissions and mtime must match.
-        os.mkdir(u"testfiles/snapshot", 0o755)
-        os.utime(u"testfiles/snapshot", (1030384548, 1030384548))
+        os.mkdir(u"{0}/testfiles/snapshot".format(_runtest_dir), 0o755)
+        os.utime(u"{0}/testfiles/snapshot".format(_runtest_dir), (1030384548, 1030384548))
         # Adjust the sigtar.gz file to have a bogus second snapshot/ entry
         # at the beginning.
-        sigtars = glob.glob(u"testfiles/output/duplicity-full*.sigtar.gz")
+        sigtars = glob.glob(u"{0}/testfiles/output/duplicity-full*.sigtar.gz".format(_runtest_dir))
         self.assertEqual(1, len(sigtars))
         sigtar = sigtars[0]
-        self.assertEqual(0, os.system(u"%s c --file=testfiles/snapshot.sigtar -C testfiles snapshot" % (tarcmd,)))
-        self.assertEqual(0, os.system(u"gunzip -c %s > testfiles/full.sigtar" % sigtar))
-        self.assertEqual(0, os.system(u"%s A --file=testfiles/snapshot.sigtar testfiles/full.sigtar" % (tarcmd,)))
-        self.assertEqual(0, os.system(u"gzip testfiles/snapshot.sigtar"))
+        self.assertEqual(0, os.system(u"{0} c --file={1}/testfiles/snapshot.sigtar -C {1}/testfiles snapshot".format(tarcmd, _runtest_dir)))
+        self.assertEqual(0, os.system(u"gunzip -c {1} > {0}/testfiles/full.sigtar".format(_runtest_dir, sigtar)))
+        self.assertEqual(0, os.system(u"{0} A --file={1}/testfiles/snapshot.sigtar {1}/testfiles/full.sigtar".format(tarcmd, _runtest_dir)))
+        self.assertEqual(0, os.system(u"gzip {0}/testfiles/snapshot.sigtar".format(_runtest_dir)))
         os.remove(sigtar)
-        os.rename(u"testfiles/snapshot.sigtar.gz", sigtar)
+        os.rename(u"{0}/testfiles/snapshot.sigtar.gz".format(_runtest_dir), sigtar)
         # Clear cache so our adjusted sigtar will be sync'd back into the cache
-        self.assertEqual(0, os.system(u"rm -r testfiles/cache"))
+        self.assertEqual(0, os.system(u"rm -r {0}/testfiles/cache".format(_runtest_dir)))
         # Try a follow on incremental (which in buggy versions, would create
         # a deleted entry for the base dir)
-        self.backup(u"inc", u"testfiles/blocktartest")
-        self.assertEqual(1, len(glob.glob(u"testfiles/output/duplicity-new*.sigtar.gz")))
+        self.backup(u"inc", u"{0}/testfiles/blocktartest".format(_runtest_dir))
+        self.assertEqual(1, len(glob.glob(u"{0}/testfiles/output/duplicity-new*.sigtar.gz".format(_runtest_dir))))
         # Confirm we can restore it (which in buggy versions, would fail)
         self.restore()
 
